pub fn answer(
offered: &SessionDescription,
local: &BrowserAudioLocal,
) -> Result<SessionDescription, ProfileError>Expand description
Emit an answer preserving the offered payload numbers and order.
pub fn answer(
offered: &SessionDescription,
local: &BrowserAudioLocal,
) -> Result<SessionDescription, ProfileError>Emit an answer preserving the offered payload numbers and order.